use chrono::NaiveDateTime;
use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize, Debug)]
pub struct OutgoingSnippet {
    pub title: String,
    pub body: String,
    pub formatted_body: String,
    pub filetype: String,
}

#[derive(Serialize, Deserialize, Debug)]
pub struct IncomingSnippet {
    pub id: i32,
    pub title: String,
    pub body: String,
    pub created_at: NaiveDateTime,
}

#[derive(Debug)]
pub struct ServerConfig {
    pub hostname: String,
    pub protocol: String,
    pub port: i32,
}

pub fn build_url_from_config(config: &ServerConfig) -> String {
    match config.port {
        80 => format!("{}://{}", config.protocol, config.hostname),
        _ => format!("{}://{}:{}", config.protocol, config.hostname, config.port),
    }
}

pub fn create_snippet(
    snippet: OutgoingSnippet,
    config: &ServerConfig,
) -> Result<IncomingSnippet, Box<std::error::Error>> {
    let client = reqwest::Client::new();
    let url = build_url_from_config(config);
    let resp: IncomingSnippet = client
        .post(&format!("{}/api/snippets", url))
        .json(&snippet)
        .send()?
        .json()?;
    Ok(resp)
}
